@@ -25,18 +25,18 @@ public:
     {
     }
 
-    QString dbPath(const QString &dbName) const;
-    QString emailIndexingPath() const;
-    QString collectionIndexingPath() const;
-    QString calendarIndexingPath() const;
-    QString akonotesIndexingPath() const;
-    QString emailContactsIndexingPath() const;
-    QString contactIndexingPath() const;
+    Q_REQUIRED_RESULT QString dbPath(const QString &dbName) const;
+    Q_REQUIRED_RESULT QString emailIndexingPath() const;
+    Q_REQUIRED_RESULT QString collectionIndexingPath() const;
+    Q_REQUIRED_RESULT QString calendarIndexingPath() const;
+    Q_REQUIRED_RESULT QString akonotesIndexingPath() const;
+    Q_REQUIRED_RESULT QString emailContactsIndexingPath() const;
+    Q_REQUIRED_RESULT QString contactIndexingPath() const;
 
     mutable QHash<QString, QString> m_cachePath;
     QString m_overridePrefixPath;
-    qlonglong indexedItems(const qlonglong id);
-    qlonglong indexedItemsInDatabase(const std::string &term, const QString &dbPath) const;
+    Q_REQUIRED_RESULT qlonglong indexedItems(const qlonglong id);
+    Q_REQUIRED_RESULT qlonglong indexedItemsInDatabase(const std::string &term, const QString &dbPath) const;
     void findIndexedInDatabase(QSet<Akonadi::Item::Id> &indexed, Akonadi::Collection::Id collectionId, const QString &dbPath);
     void findIndexed(QSet<Akonadi::Item::Id> &indexed, Akonadi::Collection::Id collectionId);
 };
@@ -115,7 +115,7 @@ qlonglong IndexedItemsPrivate::indexedItemsInDatabase(const std::string &term, c
 {
     Xapian::Database db;
     try {
-        db = Xapian::Database(QFile::encodeName(dbPath).constData());
+        db = Xapian::Database(QFile::encodeName(dbPath).toStdString());
     } catch (const Xapian::DatabaseError &e) {
         qCCritical(AKONADI_SEARCH_PIM_LOG) << "Failed to open database" << dbPath << ":" << QString::fromStdString(e.get_msg());
         return 0;
@@ -136,20 +136,39 @@ void IndexedItemsPrivate::findIndexedInDatabase(QSet<Akonadi::Item::Id> &indexed
 {
     Xapian::Database db;
     try {
-        db = Xapian::Database(QFile::encodeName(dbPath).constData());
+        db = Xapian::Database(QFile::encodeName(dbPath).toStdString());
     } catch (const Xapian::DatabaseError &e) {
         qCCritical(AKONADI_SEARCH_PIM_LOG) << "Failed to open database" << dbPath << ":" << QString::fromStdString(e.get_msg());
         return;
     }
     const std::string term = QStringLiteral("C%1").arg(collectionId).toStdString();
-    Xapian::Query query(term);
+    const Xapian::Query query(term);
     Xapian::Enquire enquire(db);
     enquire.set_query(query);
 
-    Xapian::MSet mset = enquire.get_mset(0, UINT_MAX);
-    Xapian::MSetIterator it = mset.begin();
-    for (; it != mset.end(); it++) {
-        indexed << *it;
+    auto getResults = [&enquire, &indexed]() {
+        Xapian::MSet mset;
+        mset = enquire.get_mset(0, UINT_MAX);
+        Xapian::MSetIterator it = mset.begin();
+        for (auto result : mset) {
+            indexed << result;
+        }
+    };
+
+    try {
+        getResults();
+    } catch (const Xapian::DatabaseModifiedError &e) {
+        qCCritical(AKONADI_SEARCH_PIM_LOG) << "Failed to read database" << dbPath << ":" << QString::fromStdString(e.get_msg());
+        qCCritical(AKONADI_SEARCH_PIM_LOG) << "Calling reopen() on database" << dbPath << "and trying again";
+        if (db.reopen()) { // only try again once
+            try {
+                getResults();
+            } catch (const Xapian::DatabaseModifiedError &e) {
+                qCCritical(AKONADI_SEARCH_PIM_LOG) << "Failed to query database" << dbPath << "even after calling reopen()";
+            }
+        }
+    } catch (const Xapian::DatabaseCorruptError &e) {
+        qCCritical(AKONADI_SEARCH_PIM_LOG) << "Failed to query database" << dbPath << ":" << QString::fromStdString(e.get_msg());
     }
 }
 
