@@ -70,7 +70,7 @@ void App::main()
         return;
     }
 
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(m_akonadiIds);
+    auto *job = new Akonadi::ItemFetchJob(m_akonadiIds);
     job->fetchScope().fetchFullPayload(true);
 
     connect(job, &Akonadi::ItemFetchJob::itemsReceived,
