@@ -29,20 +29,13 @@
 #include "lib/contactcompleter.h"
 #include "lib/resultiterator.h"
 
-static const QStringList sCategories = { i18n("Contacts") };
-
 Q_DECLARE_METATYPE(KContacts::Addressee *)
 
 PIMContactsRunner::PIMContactsRunner(QObject *parent, const QVariantList &args)
     : Plasma::AbstractRunner(parent, args)
-    , mQueryAutocompleter(true)
 {
     setObjectName(QStringLiteral("PIMContactsRunner"));
     setSpeed(Plasma::AbstractRunner::SlowSpeed);
-    setIgnoredTypes(Plasma::RunnerContext::FileSystem
-                    | Plasma::RunnerContext::Executable
-                    | Plasma::RunnerContext::NetworkLocation);
-
     // reloadConfiguration() called by default init() implementation
 }
 
@@ -55,20 +48,6 @@ void PIMContactsRunner::reloadConfiguration()
     mQueryAutocompleter = config().readEntry(QStringLiteral("queryAutocompleter"), true);
 }
 
-QStringList PIMContactsRunner::categories() const
-{
-    return sCategories;
-}
-
-QIcon PIMContactsRunner::categoryIcon(const QString &category) const
-{
-    if (category == sCategories[0]) {
-        return QIcon::fromTheme(QStringLiteral("view-pim-contacts"));
-    }
-
-    return Plasma::AbstractRunner::categoryIcon(category);
-}
-
 void PIMContactsRunner::match(Plasma::RunnerContext &context)
 {
     const QString queryString = context.query();
@@ -110,7 +89,7 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context, const QStr
     // a separate Session for each, otherwise things might explode
     QScopedPointer<Akonadi::Session, QScopedPointerDeleteLater> session(
         new Akonadi::Session("PIIMContactRunner-" + QByteArray::number((qlonglong)QThread::currentThread())));
-    Akonadi::ItemFetchJob *fetch = new Akonadi::ItemFetchJob(results, session.data());
+    auto *fetch = new Akonadi::ItemFetchJob(results, session.data());
     Akonadi::ItemFetchScope &scope = fetch->fetchScope();
     scope.fetchFullPayload(true);
     scope.setFetchRemoteIdentification(false);
@@ -145,7 +124,7 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context, const QStr
         }
 
         Plasma::QueryMatch match(this);
-        match.setMatchCategory(sCategories[0]);
+        match.setMatchCategory(i18n("Contacts"));
         match.setRelevance(0.75); // 0.75 is used by most runners, we don't
         // want to shadow them
         match.setMimeType(KContacts::Addressee::mimeType());
@@ -214,7 +193,7 @@ void PIMContactsRunner::queryAutocompleter(Plasma::RunnerContext &context, const
         Plasma::QueryMatch match(this);
         match.setRelevance(0.7); // slightly lower relevance than real addressbook contacts
         match.setMimeType(KContacts::Addressee::mimeType());
-        match.setMatchCategory(sCategories[0]);
+        match.setMatchCategory(i18n("Contacts"));
         match.setSubtext(i18n("Autocompleted from received and sent emails"));
         match.setIcon(QIcon::fromTheme(QStringLiteral("user-identity")));
         if (result == queryString) {
