@@ -8,7 +8,6 @@
 
 #include "xapiansearchstore.h"
 #include "xapianqueryparser.h"
-#include "term.h"
 #include "query.h"
 
 #include <QVector>
@@ -22,7 +21,6 @@ XapianSearchStore::XapianSearchStore(QObject *parent)
     : SearchStore(parent)
     , m_mutex(QMutex::Recursive)
     , m_nextId(1)
-    , m_db(nullptr)
 {
 }
 
@@ -39,7 +37,7 @@ void XapianSearchStore::setDbPath(const QString &path)
     m_db = nullptr;
 
     try {
-        m_db = new Xapian::Database(m_dbPath.toUtf8().constData());
+        m_db = new Xapian::Database(m_dbPath.toStdString());
     } catch (const Xapian::DatabaseOpeningError &) {
         qCWarning(AKONADI_SEARCH_XAPIAN_LOG) << "Xapian Database does not exist at " << m_dbPath;
     } catch (const Xapian::DatabaseCorruptError &) {
@@ -118,7 +116,7 @@ int XapianSearchStore::exec(const Query &query)
         return 0;
     }
 
-    while (1) {
+    while (true) {
         try {
             QMutexLocker lock(&m_mutex);
             try {
